==> graphql-web-lite-16.6.0-2.tgz: package/validation/rules/UniqueArgumentDefinitionNamesRule.js <==
var jsutils_groupBy = require("../../jsutils/groupBy.js");

var shared = require("../../shared.js");

exports.UniqueArgumentDefinitionNamesRule = function UniqueArgumentDefinitionNamesRule(context) {
  return {
    DirectiveDefinition(directiveNode) {
      var _directiveNode$argume;
      const argumentNodes = null !== (_directiveNode$argume = directiveNode.arguments) && void 0 !== _directiveNode$argume ? _directiveNode$argume : [];
      return checkArgUniqueness(`@${directiveNode.name.value}`, argumentNodes);
    },
    InterfaceTypeDefinition: checkArgUniquenessPerField,
    InterfaceTypeExtension: checkArgUniquenessPerField,
    ObjectTypeDefinition: checkArgUniquenessPerField,
    ObjectTypeExtension: checkArgUniquenessPerField
  };
  function checkArgUniquenessPerField(typeNode) {
    var _typeNode$fields;
    const typeName = typeNode.name.value;
    const fieldNodes = null !== (_typeNode$fields = typeNode.fields) && void 0 !== _typeNode$fields ? _typeNode$fields : [];
    for (const fieldDef of fieldNodes) {
      var _fieldDef$arguments;
      checkArgUniqueness(`${typeName}.${fieldDef.name.value}`, null !== (_fieldDef$arguments = fieldDef.arguments) && void 0 !== _fieldDef$arguments ? _fieldDef$arguments : []);
    }
    return !1;
  }
  function checkArgUniqueness(parentName, argumentNodes) {
    const seenArgs = jsutils_groupBy.groupBy(argumentNodes, (arg => arg.name.value));
    for (const [argName, argNodes] of seenArgs) {
      if (argNodes.length > 1) {
        context.reportError(new shared.GraphQLError(`Argument "${parentName}(${argName}:)" can only be defined once.`, {
          nodes: argNodes.map((node => node.name))
        }));
      }
    }
    return !1;
  }
};

==> graphql-web-lite-16.6.0-4.tgz: package/validation/rules/UniqueArgumentDefinitionNamesRule.js <==
var jsutils_groupBy = require("../../jsutils/groupBy.js");

var graphql_web = require("@0no-co/graphql.web");

exports.UniqueArgumentDefinitionNamesRule = function UniqueArgumentDefinitionNamesRule(context) {
  return {
    DirectiveDefinition(directiveNode) {
      var _directiveNode$argume;
      const argumentNodes = null !== (_directiveNode$argume = directiveNode.arguments) && void 0 !== _directiveNode$argume ? _directiveNode$argume : [];
      return checkArgUniqueness(`@${directiveNode.name.value}`, argumentNodes);
    },
    InterfaceTypeDefinition: checkArgUniquenessPerField,
    InterfaceTypeExtension: checkArgUniquenessPerField,
    ObjectTypeDefinition: checkArgUniquenessPerField,
    ObjectTypeExtension: checkArgUniquenessPerField
  };
  function checkArgUniquenessPerField(typeNode) {
    var _typeNode$fields;
    const typeName = typeNode.name.value;
    const fieldNodes = null !== (_typeNode$fields = typeNode.fields) && void 0 !== _typeNode$fields ? _typeNode$fields : [];
    for (const fieldDef of fieldNodes) {
      var _fieldDef$arguments;
      checkArgUniqueness(`${typeName}.${fieldDef.name.value}`, null !== (_fieldDef$arguments = fieldDef.arguments) && void 0 !== _fieldDef$arguments ? _fieldDef$arguments : []);
    }
    return !1;
  }
  function checkArgUniqueness(parentName, argumentNodes) {
    const seenArgs = jsutils_groupBy.groupBy(argumentNodes, (arg => arg.name.value));
    for (const [argName, argNodes] of seenArgs) {
      if (argNodes.length > 1) {
        context.reportError(new graphql_web.GraphQLError(`Argument "${parentName}(${argName}:)" can only be defined once.`, {
          nodes: argNodes.map((node => node.name))
        }));
      }
    }
    return !1;
  }
};
